<?php

namespace App\Http\Controllers\AdminArea;

use App\Models\Press;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Validator;

class PressController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $presses = Press::get();
        return view('admin.press.index', compact('presses'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.press.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate Text Fields
        $validator = Validator::make($request->all(), [
            'title' => 'required|max:255|min:1',
            'subtitle' => 'required|max:255|min:1',
            'url' => 'required|max:255|min:1',
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() ) {

            return back()->withErrors( $validator->messages() );
        }

        $file = $request->file('thumbnail');

        //Check if form exists thumbnail
        if( ! $file ){

            return back()->withErrors( 'Thumbnail is required' );
        }

        $size = $file->getSize();

        //File size should be less than 5 mb
        if($size > 5000000) return back()->withErrors( 'Max file size - 5mb' );
        $ext = $file->getClientOriginalExtension();

        if($ext !== 'jpg' && $ext !== 'jpeg' && $ext !== 'png') return back()->withErrors( 'Incorrect file format. Only Jpg, Jpeg, Png' );

        $original_name = $file->getClientOriginalName();
        $thumbnail = time().$original_name;
        $file->move(public_path() . '/uploads/press/', $thumbnail);

        $save_db = [ 'title'=>$request->input('title'), 'subtitle' => $request->input('subtitle'), 'url' => $request->input('url'), 'thumbnail'=>$thumbnail ];

        //Save form data into db
        if( ! Press::create( $save_db ) )
        {
            return back()->withErrors( 'There is error while saving your form, please try again later' );
        }

        return redirect('admin/press');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $press = Press::find( $id );
        return view('admin.press.edit', compact('press'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //Validate Text Fields
        $validator = Validator::make($request->all(), [
            'title' => 'required|max:255|min:1',
            'subtitle' => 'required|max:255|min:1',
            'url' => 'required|max:255|min:1',
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() ) {

            return back()->withErrors( $validator->messages() );
        }

        $save_db = [ 'title' => $request->input('title'), 'subtitle' => $request->input('subtitle'), 'url' => $request->input('url') ];

        $file = $request->file('thumbnail');

        //Check if form exists thumbnail
        if( $file )
        {

            $size = $file->getSize();

            //File size should be less than 5 mb
            if($size > 5000000) return back()->withErrors( 'Max file size - 5mb' );
            $ext = $file->getClientOriginalExtension();

            if($ext !== 'jpg' && $ext !== 'jpeg' && $ext !== 'png') return back()->withErrors( 'Incorrect file format. Only Jpg, Jpeg, Png' );

            $original_name = $file->getClientOriginalName();
            $thumbnail = time().$original_name;

            if( $file->move(public_path() . '/uploads/press/', $thumbnail) ) {

                $press = Press::find($id);
                $current_thumbnail = $press->thumbnail;
                File::delete(public_path('uploads/press/'.$current_thumbnail));
                $save_db['thumbnail'] = $thumbnail;
            }
        }

        //Save form data into db
        if( ! Press::where('id', $id)->update( $save_db ) )
        {
            return back()->withErrors( 'There is error while saving your form, please try again later' );
        }

        return redirect('admin/press');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $press = Press::find($id);
        if( Press::where('id',$id)->delete() )
        {
            $thumbnail = $press->thumbnail;
            $thumnail_path = public_path('uploads/press/'.$thumbnail);
            File::delete($thumnail_path);
        }

        return redirect('admin/press');
    }
}
