<?php

namespace App\Http\Controllers\AdminArea;

use App\Models\ProductImage;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Product;
use Illuminate\Support\Facades\Validator;

class ProductsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $products = Product::with('category')->where('status', 'active')->get();
        return view('admin.products.index', compact('products'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $categories = Category::where('status', 'active')->get();
        return view('admin.products.create', compact('categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        //Validate Text Fields
        $validator = Validator::make($request->all(), [
            'name' => 'required|max:255|min:2',
            'description' => 'required',
            'slug' => 'required|min:2',
            'category_id' => 'required|numeric',
            'images.*' => "mimes:jpg,jpeg,png,bmp,tiff|max:5000"
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() )
        {
            return back()->withErrors( $validator->messages() );
        }

        $save_db = [
            'name'        =>$request->input('name'),
            'description' => $request->input('description'),
            'slug'        => $request->input('slug'),
            'category_id' => $request->input('category_id'),
            'attributes'  => 'replace later'
        ];

        //Save form data into db
        $product = Product::create( $save_db );
        if( ! $product )
        {
            return back()->withErrors( 'There is error while saving your form, please try again later' );
        }

        if($request->hasFile("images")){
            $images = $request->file("images");
            foreach ($images as $index => $image){
                $fileName = $image->getClientOriginalName();
                $newFileName = time() . $index . $fileName;
                $image->move(public_path() . "/uploads/products/", $newFileName);
                $productImage = new ProductImage();
                $productImage->product_id = $product->id;
                $productImage->file_name = $newFileName;
                $productImage->save();
            }
        }

        return redirect('admin/products');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $categories = Category::where('status', 'active')->get();
        $product = Product::where('id', $id)->with(['category', "images"])->first();
        return view('admin.products.edit', compact('product', 'categories'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required|max:255|min:2',
            'description' => 'required',
            'slug' => 'required|min:2',
            'category_id' => 'required|numeric',
            'images.*' => "mimes:jpg,jpeg,png,bmp,tiff|max:5000"
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() )
        {
            return back()->withErrors( $validator->messages() );
        }
        //
        $product = Product::find($id);
        $product->name = $request->input("name");
        $product->description = $request->input("description");
        $product->slug = $request->input("slug");
        $product->category_id = $request->input("category_id");
        $product->save();
        if($request->hasFile("images")){
            $images = $request->file("images");
            foreach ($images as $index => $image){
                $fileName = $image->getClientOriginalName();
                $newFileName = time() . $index . $fileName;
                $image->move(public_path() . "/uploads/products/", $newFileName);
                $productImage = new ProductImage();
                $productImage->product_id = $id;
                $productImage->file_name = $newFileName;
                $productImage->save();
            }
        }
        return redirect()->route("products.index");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Product::where('id',$id)->update( ['status' => 'deleted'] );
        return redirect('admin/products');
    }

    /**
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function deleteImage($id){
        $image = ProductImage::findOrFail($id);
        $filePath = public_path() . "/uploads/products/" . $image->file_name;
        if(file_exists($filePath)){
            unlink($filePath);
            $image->delete();
        } else {
            $image->delete();
        }
        return ["success" => true, "message" => "The Image Is Successfully Deleted"];
    }
}
