<?php

namespace App\Http\Controllers\AdminArea;

use App\File;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Support\Facades\Auth;

class UsersController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $users = User::where( 'id' , '!=' , Auth::id() )->get();
        return view('admin.users.index', ['users'=>$users]);
    }

    public function dailySchedulers()
    {

        $files = File::get();
        return view('admin.dashboard.index', compact('files'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.users.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        $user_add = User::add_users( $request->all() );

        if( ! $user_add['success'] ) {

            return back()->withErrors( $user_add['message'] );
        }

        return redirect('/users');


    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        $user = User::find($id);
        return view('admin.users.edit', ['user'=>$user]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {

        $update_user = User::update_user($request->all() , $id);

        if( ! $update_user['success'] ) {

            return back()->withErrors( $update_user['message'] );
        }

        return redirect('/users');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        User::delete_user( $id );
        return redirect('users');
    }

    public function getPersonalEdit() {

        $user = Auth::user();
        $user = User::find( $user->id );
        return view('admin.users.personal_edit', ['user'=>$user]);
    }

    public function search(Request $request){
        $keyword = $request->input('keyword');
        $users = [];
        if($keyword) $users = User::search($keyword);
        return view('admin.users.index', compact('users'));
    }
}
