<?php

namespace App;

use Illuminate\Notifications\Notifiable;
use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;

class User extends Authenticatable
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'email', 'password', 'role'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    public static function getUsers(){
        $users = User::where('role', '<>', 'admin')->get(['id', 'name', 'email', 'role', 'created_at', 'updated_at']);
        return $users;
    }

    public static function delete_user( $id ){
        self::where('id', $id)->delete();
        return true;
    }


    public static function add_users($request){

        $validator = Validator::make($request, [
            'name' => 'required|max:30|min:1',
            'email' => 'required|max:30|min:1|unique:users',
            'password' => 'required|max:30|min:6',
            'role' => 'required|in:admin,user_sub,user_sdva'
        ]);

        if( $validator->fails() ) {
            return ['success' => false, 'message' => $validator->messages()];
        }

        $user = new User();
        $user->name = $request['name'];
        $user->email = $request['email'];
        $user->role = $request['role'];
        $user->password = Hash::make($request['password']);
        $user->save();
        return ['success' => true];
    }


    public static function update_user($request, $id){
        $user = User::find($id);
        if ($request['password'] != null){
            $validator = Validator::make($request, [
                'password' => 'max:30|min:6',
            ]);

            if( $validator->fails() ) {
                return ['success' => false, 'message' => $validator->messages()];
            }

            $user->password = Hash::make($request['password']);
        }

        $validator = Validator::make($request, [
            'name' => 'max:30|min:1',
            'email' => 'max:30|min:1',
        ]);

        if( $validator->fails() ) {
            return ['success' => false, 'message' => $validator->messages()];
        }

        $exist_email = User::where('email' , $request['email'])->get()->toArray();
        if (!empty($exist_email) && $exist_email){
        }else{
            $user->email = $request['email'];
        }
        $user->name = $request['name'];
        if(array_key_exists('role', $request)) $user->role = $request['role'];
        $user->save();
        return ['success' => true];
    }

    public static function search($keyword){
        $users = User::where('role', '<>', 'admin')->where(function ($query) use ($keyword){
            $query->where('name', 'LIKE', '%'.$keyword.'%')->orWhere('email', 'LIKE', '%'.$keyword.'%');
        })->get(['id', 'name', 'email', 'role', 'created_at', 'updated_at']);
        return $users;
    }
}
