<?php

namespace App\Http\Controllers\AdminArea;

use App\Models\Category;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Validator;

class CategoriesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = Category::where('status', 'active')->get();
        return view('admin.categories.index', compact('categories') );
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.categories.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate Text Fields
        $validator = Validator::make($request->all(), [
            'name' => 'required|max:255|min:1',
            'slug' => 'required|max:255|min:1|unique:categories',
            'description' => 'required',
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() ) {

            return back()->withErrors( $validator->messages() );
        }

        $file = $request->file('thumbnail');

        //Check if form exists thumbnail
        if( ! $file ){

            return back()->withErrors( 'Thumbnail is required' );
        }

        $size = $file->getSize();

        //File size should be less than 5 mb
        if($size > 5000000) return back()->withErrors( 'Max file size - 5mb' );
        $ext = $file->getClientOriginalExtension();

        if($ext !== 'jpg' && $ext !== 'jpeg' && $ext !== 'png') return back()->withErrors( 'Incorrect file format. Only Jpg, Jpeg, Png' );

        $original_name = $file->getClientOriginalName();
        $thumbnail = time().$original_name;
        $file->move(public_path() . '/uploads/categories/', $thumbnail);

        $save_db = [ 'name'=>$request->input('name'),'slug'=>$request->input('slug'), 'description' => $request->input('description'), 'thumbnail'=>$thumbnail ];

        //Save form data into db
        if( ! Category::create( $save_db ) )
        {
            return back()->withErrors( 'There is error while saving your form, please try again later' );
        }

        return redirect('admin/categories');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $category = Category::find( $id );
        return view('admin.categories.edit', compact('category'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //Validate Text Fields
        $validator = Validator::make($request->all(), [
            'name' => 'required|max:255|min:1',
            'slug' => 'required|max:255|min:1',
            'description' => 'required',
        ]);

        //If text fields not valid, throw back immediatelly
        if( $validator->fails() ) {

            return back()->withErrors( $validator->messages() );
        }

        $save_db = [ 'name' => $request->input('name'), 'slug' => $request->input('slug'), 'description' => $request->input('description') ];

        $file = $request->file('thumbnail');

        //Check if form exists thumbnail
        if( $file )
        {

            $size = $file->getSize();

            //File size should be less than 5 mb
            if($size > 5000000) return back()->withErrors( 'Max file size - 5mb' );
            $ext = $file->getClientOriginalExtension();

            if($ext !== 'jpg' && $ext !== 'jpeg' && $ext !== 'png') return back()->withErrors( 'Incorrect file format. Only Jpg, Jpeg, Png' );

            $original_name = $file->getClientOriginalName();
            $thumbnail = time().$original_name;

            if( $file->move(public_path() . '/uploads/categories/', $thumbnail) ) {

                $category = Category::find($id);
                $current_thumbnail = $category->thumbnail;
                File::delete(public_path('uploads/categories/'.$current_thumbnail));
                $save_db['thumbnail'] = $thumbnail;
            }
        }

        //Save form data into db
        if( ! Category::where('id', $id)->update( $save_db ) )
        {
            return back()->withErrors( 'There is error while saving your form, please try again later' );
        }

        return redirect('admin/categories');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Category::where('id',$id)->update( ['status' => 'deleted'] );
        return redirect('admin/categories');
    }
}
