<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Inquire;
use App\Models\Press;
use App\Models\Product;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Response;

class FrontPagesController extends Controller
{
    public function getIndex()
    {
        $categories = Category::where('status','active')->get();
        return view('front.pages.home', compact('categories'));
    }

    public function getAbout()
    {
        $presses = Press::select("*");
        $count = $presses->count();
        $presses = $presses->take(Press::ABOUT_PAGIATION)->get();
        return view('front.pages.about', compact('presses', "count"));
    }

    public function getPresses(Request $request){
        $page = $request->input("page");
        $presses = Press::skip($page * Press::ABOUT_PAGIATION)->take(Press::ABOUT_PAGIATION)->get();
        return $presses;
    }

    public function getContact()
    {
        return view('front.pages.contact');
    }

    public function getPress()
    {
        $presses = Press::get();
        return view('front.pages.press', compact('presses'));
    }

    public function getObjects()
    {
        $all_products    = Product::with('images','category')->where('status','active')->get();
        $all_categories = Category::with('products')->where('status','active')->get();

        return view('front.pages.objects', compact('all_products', 'all_categories'));
    }

    public function getExactCategory( $slug ){

        $category = Category::where('slug', $slug)->first();
        if( ! $category ) return redirect(url('/'));
        $cId = $category->id;

        $products = Product::where('category_id',$cId)->where('status','active')->with('images')->get();
        return view('front.pages.exactcategoryproducts', compact('products', 'category'));
    }

    public function getProductFront($c_slug, $p_slug) {

        $category = Category::where('slug', $c_slug)->first();

        if( ! $category ) return redirect(url('/'));

        $cId = $category->id;

        $product = Product::where('slug', $p_slug)->with('images', 'category')->first();

        if( ! $product ) return redirect(url('/'));

        $similiars = Product::where('id','!=', $product->id)->where('category_id',$cId)->where('status','active')->with('images', 'category')->inRandomOrder()->take(6)->get();

        return view('front.pages.productpage', compact('product', 'similiars'));
    }

    public function partPress( $page )
    {
        $presses = Press::take(Press::ABOUT_PAGIATION * $page)->get();
        $count = Press::count();
        return view('front.pages.press', compact("presses", "count"));
    }

    public function downloadCatalog(){

        $file= public_path(). "/assets/FactureStudioCatalog.pdf";

        $headers = array(
            'Content-Type: application/pdf',
        );

        return Response::download($file, 'FactureStudioCatalog.pdf', $headers);
    }

    public function storeInquire(Request $request){
        Inquire::create($request->all());
        return ["success" => true];
    }

}
