$(document).ready(function () {
    var all_files = null;
    $('.table').DataTable();
    $.ajaxSetup({
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        }
    });

    $.ajax({
        url: "/all_files",
        method: "get",
        dataType: "json",
        success: function (data) {
            all_files = data;
        }
    });

    $('.set-in-process').on('change', function () {
        if(this.checked){
            let id = $(this).attr('data-id');
            $.ajax({
                url: "/process/add/" + id,
                method: "get",
                success: function (e) {
                    window.location.href = '/';
                }
            });
        }
    });

    $('input[name="doc"]').on('change', function (e) {
        $('.upload-error').addClass('hidden');
        if(e.target.files){
            let file = e.target.files[0];
            if(file.size > 5000000) $('.upload-error').removeClass('hidden');
            let tmp = file.name.split('.');
            let ext = tmp[tmp.length - 1];
            if(ext !== 'csv' && ext !== 'xls' && ext !== 'xlsx') $('.upload-error').removeClass('hidden');
        }
    });

    $('.remove-in-process').on('change', function () {
        if(!this.checked){
            let id = $(this).attr('data-id');
            $.ajax({
                url: "/process/remove/" + id,
                method: "get",
                success: function (e) {
                    window.location.href = '/';
                }
            });
        }
    });

    $(document).on('click', '.edit-note', function () {
        let val = $(this).html();
        let input = $(this).parent().find('input');
        if(val !== 'Click to add note') input.val(val);
        $(this).addClass('hidden');
        $(this).parent().find('.note').removeClass('hidden');
        setTimeout(function () {
            input.focus();
        }, 100);
    });

    var timeout = null;

    $(document).on('keyup', '.new-note', function () {
        let id = $(this).attr('data-id');
        let val = $(this).val();
        let el = $(this).parent().parent().find('.edit-note');
        if(timeout) clearTimeout(timeout);
        timeout = setTimeout(function () {
            $.ajax({
                url: "/note/" + id,
                method: "post",
                data: {id:id, note:val},
                success: function (e) {
                    el.html(val);
                }
            });
        }, 500);
    });

    $(document).on('blur', '.new-note', function () {
        $(this).parent().parent().find('.edit-note').removeClass('hidden');
        $(this).parent().addClass('hidden');
    });

    setInterval(function () {
        let role = $('#user_role').val();
        if(role !== 'user_sdva') return;
        $.ajax({
            url: "/all_files",
            method: "get",
            dataType: "json",
            success: function (data) {
                checkChanged(data);
            }
        });
    }, 5000);

    checkChanged = function (data) {
        let changed = false;
        if(data.length !== all_files.length) changed = true;
        for(let all_el of all_files){
            for(let data_el of data){
                if(data_el.id === all_el.id && data_el.in_process !== all_el.in_process) changed = true;
            }
        }
        if(changed){
            all_files = data;
            updateFiles(data);
        }
    };

    updateFiles = function (data) {
        let posted = $('.files-posted tbody');
        let scheduled = $('.files-scheduled tbody');
        $('.table').DataTable().destroy();
        posted.empty();
        scheduled.empty();
        setTimeout(function () {
            for(let item of data){
                if(!item.in_process) posted.append(fileRowPostedTemplate(item));
                else scheduled.append(fileRowScheduledTemplate(item));
            }
            $('.table').DataTable();
        }, 10);
    };

    fileRowPostedTemplate = function(file){
        return `
            <tr>
                <td>${file.id}</td>
                <td class="file-download">
                    <a href="${file.path}" download="${file.name}"><i class="ion-android-download"></i></a>
                </td>
                <td>${file.name}</td>
                <td>${file.created_at}</td>
                <td>
                    <div class="edit-note">${file.note ? file.note : 'Click to add note'}</div>
                    <div class="note hidden">
                        <input type="text" class="new-note" data-id="${file.id}">
                    </div>
                </td>
            </tr>
        `;
    };

    fileRowScheduledTemplate = function(file){
        return `
            <tr>
                <td>${file.id}</td>
                <td class="file-download">
                    <a href="${file.path}" download="${file.name}"><i class="ion-android-download"></i></a>
                </td>
                <td>${file.name}</td>
                <td>${file.created_at}</td>
                <td>
                    <div class="edit-note">${file.note ? file.note : 'Click to add note'}</div>
                    <div class="note hidden">
                        <input type="text" class="new-note" data-id="${file.id}">
                    </div>
                </td>
                <td>${file.acknowledged}</td>
            </tr>
        `;
    }
});
